@@ -1,5 +1,6 @@
 package Mojolicious::Plugin::Crud;
 use Mojo::Base 'Mojolicious::Plugin';
+use Data::Dumper;
 
 use Lingua::EN::Inflect qw/PL/;
 use Mojo::Util qw( camelize );
@@ -7,7 +8,7 @@ use Mojo::Util qw( camelize );
 #------------------------------------------------------------------------------
 #   Crud 版本信息
 #------------------------------------------------------------------------------
-our $VERSION = '0.0.5';
+our $VERSION = '0.0.6';
 
 #------------------------------------------------------------------------------
 #   Crud 插件注册方法
@@ -56,15 +57,15 @@ sub register {
       $resource = $r->under(
         "/$route_part/:id" => sub {
           my ($c) = @_;
-          my $msg = "Write data: \$c->stash('form_id')->{'%s'} = %s", $name, $c->param("id");
-          $c->app->log->debug( sprintf $msg );
+          my $id = $c->param("id");
+          $c->app->log->debug( sprintf( "Storable: \$c->stash('form_id')->{'%s'} = %s", $name, $id ) );
 
           # 检查是否存在$c->stash('fm.ids')，并写入 URI 表单ID
           $c->stash( 'form_id' => {} ) unless $c->stash('form_id');
           $c->stash('form_id')->{$name} = $c->param("id");
           return 1;
         }
-      )->to( controller => $controller, idname => "${name}id" );
+      )->to( controller => $controller, idname => "id" );
 
       #------------------------------------------------------
       # 接收 GET 请求，处理单 id 数据查询
